@@ -1,3 +1,9 @@
+/*
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ */
+
 #ifndef OBEXCLIENT_H
 #define OBEXCLIENT_H
 
@@ -13,7 +19,7 @@ class ObexClient : public QDBusAbstractAdaptor, public Object
     Q_CLASSINFO("D-Bus Interface", "org.bluez.obex.Client1")
 
 public:
-    explicit ObexClient(QObject *parent = Q_NULLPTR);
+    explicit ObexClient(QObject *parent = nullptr);
 
     void runAction(const QString &actionName, const QVariantMap &properties);
 
